@@ -1,5 +1,5 @@
-# copyright 2006-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
-# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
+# copyright 2006-2020 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# contact https://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of logilab-mtconverter.
 #
@@ -14,22 +14,34 @@
 # for more details.
 #
 # You should have received a copy of the GNU Lesser General Public License along
-# with logilab-mtconverter. If not, see <http://www.gnu.org/licenses/>.
+# with logilab-mtconverter. If not, see <https://www.gnu.org/licenses/>.
 """mtconverter packaging information"""
 
 modname = "mtconverter"
 distname = "logilab-mtconverter"
 subpackage_of = 'logilab'
-numversion = (0, 8, 2)
+
+numversion = (0, 9, 1)
 version = '.'.join([str(num) for num in numversion])
 
 license = 'LGPL'
+web = "https://www.logilab.org/project/%s" % distname
+mailinglist = "mailto://python-projects@lists.logilab.org"
 
-author = "Sylvain Thenault"
+description = "a library to convert from a MIME type to another"
+author = "Nicolas Chauvat"
 author_email = "contact@logilab.fr"
 
-short_desc = "a library to convert from a MIME type to another"
-long_desc = """This package is originally a backport of Zope's PortalTransforms tool with
-all Zope's internal removed (e.g. most of the code).
-"""
-web = "http://www.logilab.org/project/logilab-mtconverter"
+install_requires = [
+    'setuptools',
+    'six >= 1.4.0',
+    'logilab-common',
+    'lxml',
+    'html2text',
+]
+
+classifiers = [
+    "Programming Language :: Python",
+    "Programming Language :: Python :: 2",
+    "Programming Language :: Python :: 3",
+]
