@@ -1,4 +1,4 @@
-# copyright 2006-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2006-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of logilab-mtconverter.
@@ -16,14 +16,16 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with logilab-mtconverter. If not, see <http://www.gnu.org/licenses/>.
 from logilab.common.testlib import TestCase, unittest_main
-import urllib
+from six.moves.urllib.parse import unquote as url_unquote
 import re
+import os.path as osp
 
 from logilab.mtconverter import TransformData, TransformError
 from logilab.mtconverter.transforms import text_to_text
 from logilab.mtconverter.transform import Transform, TransformsChain
 from logilab.mtconverter.engine import TransformEngine
 
+DATAPATH = osp.dirname(__file__)
 
 class HtmlToText(Transform):
     inputs = ('text/html',)
@@ -31,7 +33,7 @@ class HtmlToText(Transform):
 
     def __call__(self, orig):
         orig = re.sub('<[^>]*>(?i)(?m)', '', orig)
-        return urllib.unquote(re.sub('\n+', '\n', orig)).strip()
+        return url_unquote(re.sub('\n+', '\n', orig)).strip()
 
     def _convert(self, data):
         return self.__call__(data.data)
@@ -45,7 +47,7 @@ class FooToBar(Transform):
 
     def __call__(self, orig):
         orig = re.sub('foo', 'bar', orig)
-        return urllib.unquote(re.sub('\n+', '\n', orig)).strip()
+        return url_unquote(re.sub('\n+', '\n', orig)).strip()
 
     def _convert(self, data):
         return self.__call__(data.data)
@@ -91,7 +93,7 @@ def html_data():
 class EngineTC(TestCase):
     def setUp(self):
         self.engine = TransformEngine()
-        
+
     def register(self):
         #A default set of transforms to prove the interfaces work
         self.engine.add_transform(HtmlToText())
@@ -109,37 +111,37 @@ class EngineTC(TestCase):
 
     def test_has_input(self):
         self.register()
-        self.failUnless(self.engine.has_input('text/html'))
-        self.failUnless(self.engine.has_input('text/plain'))
-        self.failUnless(self.engine.has_input('text/whatever'))
-        self.failIf(self.engine.has_input('application/octet-stream'))
-                        
+        self.assertTrue(self.engine.has_input('text/html'))
+        self.assertTrue(self.engine.has_input('text/plain'))
+        self.assertTrue(self.engine.has_input('text/whatever'))
+        self.assertFalse(self.engine.has_input('application/octet-stream'))
+
     def test_convert(self):
         self.register()
         self.engine.add_transform(text_to_text())
-        
+
         data = TransformData("This is a test", 'text/x-diff', 'ascii')
         out = self.engine.convert(data, 'text/plain')
-        self.failUnlessEqual(out.data, "This is a test")
-        self.failUnlessEqual(out.mimetype, 'text/plain')
-        self.failUnlessEqual(out.encoding, 'ascii')
+        self.assertEqual(out.data, "This is a test")
+        self.assertEqual(out.mimetype, 'text/plain')
+        self.assertEqual(out.encoding, 'ascii')
 
         # html_to_text transform should take priority over text_to_text
         data = self.engine.convert(html_data(), "text/plain")
-        self.failUnlessEqual(data.data, "foo")
-        self.failUnlessEqual(data.mimetype, 'text/plain')
-        self.failUnlessEqual(data.encoding, 'ascii')
-        
+        self.assertEqual(data.data, "foo")
+        self.assertEqual(data.mimetype, 'text/plain')
+        self.assertEqual(data.encoding, 'ascii')
+
         self.engine.remove_transform('HtmlToText')
         self.engine.remove_transform('FooToBar')
         self.engine.add_transform(HtmlToTextWithEncoding())
         data = self.engine.convert(html_data(), "text/plain")
-        self.failUnlessEqual(data.mimetype, 'text/plain')
-        self.failUnlessEqual(data.encoding, 'utf8')
+        self.assertEqual(data.mimetype, 'text/plain')
+        self.assertEqual(data.encoding, 'utf8')
 
         self.engine.add_transform(FooToBar())
         data = self.engine.convert(html_data(), 'text/bar')
-        self.failUnlessEqual(data.data, "<b>bar</b>")
+        self.assertEqual(data.data, "<b>bar</b>")
 
     def test_chain(self):
         #self.register()
@@ -148,25 +150,25 @@ class EngineTC(TestCase):
         hb.append(FooToBar())
         self.engine.add_transform(hb)
         cache = self.engine.convert(html_data(), 'text/bar')
-        self.failUnlessEqual(cache.data, "bar")
+        self.assertEqual(cache.data, "bar")
 
     def test_same(self):
         data = TransformData("This is a test", 'text/plain', 'ascii')
         out = self.engine.convert(data, 'text/plain')
-        self.failUnlessEqual(out.data, "This is a test")
-        self.failUnlessEqual(out.mimetype, 'text/plain')
-        self.failUnlessEqual(out.encoding, 'ascii')
-        
+        self.assertEqual(out.data, "This is a test")
+        self.assertEqual(out.mimetype, 'text/plain')
+        self.assertEqual(out.encoding, 'ascii')
+
         self.engine.add_transform(HtmlIdTransform())
         out = self.engine.convert(html_data(), 'text/html')
-        self.failUnlessEqual(out.data, "<b>foo</b> transformed")
-        self.failUnlessEqual(out.mimetype, 'text/html')
-        self.failUnlessEqual(out.encoding, 'ascii')
+        self.assertEqual(out.data, "<b>foo</b> transformed")
+        self.assertEqual(out.mimetype, 'text/html')
+        self.assertEqual(out.encoding, 'ascii')
+
 
-                                
     def test_convert_compressed(self):
         self.register()
-        data = TransformData(open('data.txt.gz', 'rb').read(), 'text/plain', 'gzip')
+        data = TransformData(open(osp.join(DATAPATH, 'data.txt.gz'), 'rb').read(), 'text/plain', 'gzip')
         self.assertRaises(TransformError, self.engine.convert, data, 'text/plain')
         self.engine.add_transform(text_to_text())
         self.assertRaises(TransformError, self.engine.convert, data, 'text/plain')
